@@ -41,8 +41,11 @@ collision_list = [
     "_warnings",
     "select_eq",
     "select_gt",
+    "select_gte",
     "select_lt",
+    "select_lte",
     "_adjust",
+    "_delete",
     "_numpy_type",
     "_parse_errors",
     "_resolve_order",
@@ -56,6 +59,7 @@ collision_list = [
     "_defaults_schema",
     "operators",
     "adjust",
+    "delete",
     "array_first",
     "clear_state",
     "defaults",
