@@ -12,7 +12,14 @@ from marshmallow import ValidationError as MarshmallowValidationError
 from paramtools import utils
 from paramtools.schema import ParamToolsSchema
 from paramtools.schema_factory import SchemaFactory
-from paramtools.select import select_eq, select_gt_ix, select_gt, select_lt
+from paramtools.select import (
+    select_eq,
+    select_gt_ix,
+    select_gt,
+    select_gte,
+    select_lt,
+    select_lte,
+)
 from paramtools.tree import Tree
 from paramtools.typing import ValueObject
 from paramtools.exceptions import (
@@ -170,20 +177,23 @@ class Parameters:
         ignore_warnings=False,
         raise_errors=True,
         extend_adj=True,
+        is_deserialized=False,
     ):
         """
         Internal method for performing adjustments.
         """
-        params = self.read_params(params_or_path)
-
         # Validate user adjustments.
-        parsed_params = {}
-        try:
-            parsed_params = self._validator_schema.load(
-                params, ignore_warnings
-            )
-        except MarshmallowValidationError as ve:
-            self._parse_validation_messages(ve.messages, params)
+        if is_deserialized:
+            parsed_params = params_or_path
+        else:
+            params = self.read_params(params_or_path)
+            parsed_params = {}
+            try:
+                parsed_params = self._validator_schema.load(
+                    params, ignore_warnings
+                )
+            except MarshmallowValidationError as ve:
+                self._parse_validation_messages(ve.messages, params)
 
         if not self._errors:
             if self.label_to_extend is not None and extend_adj:
@@ -267,6 +277,64 @@ class Parameters:
 
         return parsed_params
 
+    def delete(
+        self,
+        params_or_path,
+        ignore_warnings=False,
+        raise_errors=True,
+        extend_adj=True,
+    ):
+        """
+        Delete value objects in params_or_path.
+
+        Returns: adjustment for deleting parameters.
+
+        Raises:
+            marshmallow.exceptions.ValidationError if data is not valid.
+
+            ParameterUpdateException if label values do not match at
+                least one existing value item's corresponding label values.
+        """
+        return self._delete(
+            params_or_path,
+            ignore_warnings=ignore_warnings,
+            raise_errors=raise_errors,
+            extend_adj=extend_adj,
+        )
+
+    def _delete(
+        self,
+        params_or_path,
+        ignore_warnings=False,
+        raise_errors=True,
+        extend_adj=True,
+    ):
+        """
+        Internal method that sets the 'value' member for all value objects
+        to None. Value objects with 'value' set to None are deleted.
+        """
+        params = self.read_params(params_or_path)
+        # Validate user adjustments.
+        parsed_params = {}
+        try:
+            parsed_params = self._validator_schema.load(
+                params, ignore_warnings=True
+            )
+        except MarshmallowValidationError as ve:
+            self._parse_validation_messages(ve.messages, params)
+
+        to_delete = {}
+        for param, vos in parsed_params.items():
+            to_delete[param] = [dict(vo, **{"value": None}) for vo in vos]
+
+        return self._adjust(
+            to_delete,
+            ignore_warnings=ignore_warnings,
+            raise_errors=raise_errors,
+            extend_adj=extend_adj,
+            is_deserialized=True,
+        )
+
     @property
     def errors(self):
         if not self._errors:
@@ -729,7 +797,7 @@ class Parameters:
             self._validator_schema.fields[param].schema.fields["value"].np_type
         )
 
-    def select_eq(self, param, exact_match, **labels):
+    def select_eq(self, param, exact_match=True, **labels):
         return select_eq(
             self._data[param]["value"],
             exact_match,
@@ -737,7 +805,7 @@ class Parameters:
             tree=self._search_trees.get(param),
         )
 
-    def select_gt(self, param, exact_match, **labels):
+    def select_gt(self, param, exact_match=True, **labels):
         return select_gt(
             self._data[param]["value"],
             exact_match,
@@ -745,7 +813,15 @@ class Parameters:
             tree=self._search_trees.get(param),
         )
 
-    def select_lt(self, param, exact_match, **labels):
+    def select_gte(self, param, exact_match=True, **labels):
+        return select_gte(
+            self._data[param]["value"],
+            exact_match,
+            labels,
+            tree=self._search_trees.get(param),
+        )
+
+    def select_lt(self, param, exact_match=True, **labels):
         return select_lt(
             self._data[param]["value"],
             exact_match,
@@ -753,6 +829,14 @@ class Parameters:
             tree=self._search_trees.get(param),
         )
 
+    def select_lte(self, param, exact_match=True, **labels):
+        return select_lte(
+            self._data[param]["value"],
+            exact_match,
+            labels,
+            tree=self._search_trees.get(param),
+        )
+
     def _update_param(self, param, new_values):
         """
         Update the current parameter values with those specified by
