@@ -715,13 +715,13 @@ class TestValidationMessages:
         with pytest.raises(ValidationError) as excinfo:
             params.adjust(adj)
 
-        exp_user_message = {"min_int_param": ["Not a valid number: abc."]}
+        exp_user_message = {"min_int_param": ["Not a valid integer: abc."]}
         assert json.loads(excinfo.value.args[0]) == {
             "errors": exp_user_message
         }
 
         exp_internal_message = {
-            "min_int_param": [["Not a valid number: abc."]]
+            "min_int_param": [["Not a valid integer: abc."]]
         }
         assert excinfo.value.messages["errors"] == exp_internal_message
 
@@ -733,6 +733,27 @@ class TestValidationMessages:
         with pytest.raises(ValidationError) as excinfo:
             params.adjust(adj)
 
+    def test_label_errors(self, TestParams):
+        params = TestParams()
+
+        params.adjust(
+            {"min_int_param": [{"value": 2, "label1": 6}]}, raise_errors=False
+        )
+
+        assert params.errors["min_int_param"] == [
+            "Input 6 must be less than 5."
+        ]
+
+        params = TestParams()
+
+        params.adjust(
+            {"min_int_param": [{"value": 2, "label1": -1}]}, raise_errors=False
+        )
+
+        assert params.errors["min_int_param"] == [
+            "Input -1 must be greater than 0."
+        ]
+
     def test_errors_choice_param(self, TestParams):
         params = TestParams()
         adjustment = {"str_choice_param": [{"value": "not a valid choice"}]}
@@ -789,13 +810,11 @@ class TestValidationMessages:
     def test_errors_int_param(self, TestParams):
         params = TestParams()
         adjustment = {
-            "min_int_param": [
-                {"label0": "zero", "label1": 1, "value": "not a number"}
-            ]
+            "min_int_param": [{"label0": "zero", "label1": 1, "value": 2.5}]
         }
 
         params.adjust(adjustment, raise_errors=False)
-        exp = {"min_int_param": ["Not a valid number: not a number."]}
+        exp = {"min_int_param": ["Not a valid integer: 2.5."]}
         assert params.errors == exp
 
     def test_errors_multiple_params(self, TestParams):
@@ -813,8 +832,8 @@ class TestValidationMessages:
         params.adjust(adjustment, raise_errors=False)
         exp = {
             "min_int_param": [
-                "Not a valid number: not a number.",
-                "Not a valid number: still not a number.",
+                "Not a valid integer: not a number.",
+                "Not a valid integer: still not a number.",
             ],
             "date_param": ["Not a valid date: not a date."],
         }
@@ -858,6 +877,20 @@ class TestValidationMessages:
         }
         assert excinfo.value.labels["errors"] == exp_labels
 
+        params = TestParams()
+        adjustment = {"float_param": [2.5]}
+
+        params.adjust(adjustment, raise_errors=False)
+        exp = {"float_param": ["Not a valid number: [2.5]."]}
+        assert params.errors == exp
+
+        params = TestParams()
+        adjustment = {"bool_param": [False]}
+
+        params.adjust(adjustment, raise_errors=False)
+        exp = {"bool_param": ["Not a valid boolean: [False]."]}
+        assert params.errors == exp
+
     def test_range_validation_on_list_param(self, TestParams):
         params = TestParams()
         adj = {
